@@ -127,54 +127,59 @@ var (
 	podQueries = &querys{
 		query{
 			Name:        "pod-limit-cpu-cores",
-			QueryString: "sum(kube_pod_container_resource_limits{resource='cpu'}) by (pod, namespace, node)",
+			Chunked:     true,
+			QueryString: "sum(kube_pod_container_resource_limits{resource='cpu'} * on(pod, namespace) group_left kube_pod_status_phase{phase='Running'}) by (pod, namespace, node)",
 			MetricKey:   staticFields{"pod": "pod", "namespace": "namespace", "node": "node"},
 			QueryValue: &saveQueryValue{
 				ValName:         "pod-limit-cpu-cores",
-				Method:          "max",
-				Factor:          maxFactor,
+				Method:          "sum",
+				Factor:          sumFactor,
 				TransformedName: "pod-limit-cpu-core-seconds",
 			},
 			RowKey: "pod",
 		},
 		query{
 			Name:        "pod-limit-memory-bytes",
-			QueryString: "sum(kube_pod_container_resource_limits{resource='memory'}) by (pod, namespace, node)",
+			Chunked:     true,
+			QueryString: "sum(kube_pod_container_resource_limits{resource='memory'} * on(pod, namespace) group_left kube_pod_status_phase{phase='Running'}) by (pod, namespace, node)",
 			MetricKey:   staticFields{"pod": "pod", "namespace": "namespace", "node": "node"},
 			QueryValue: &saveQueryValue{
 				ValName:         "pod-limit-memory-bytes",
-				Method:          "max",
-				Factor:          maxFactor,
+				Method:          "sum",
+				Factor:          sumFactor,
 				TransformedName: "pod-limit-memory-byte-seconds",
 			},
 			RowKey: "pod",
 		},
 		query{
 			Name:        "pod-request-cpu-cores",
-			QueryString: "sum(kube_pod_container_resource_requests{resource='cpu'}) by (pod, namespace, node)",
+			Chunked:     true,
+			QueryString: "sum(kube_pod_container_resource_requests{resource='cpu'} * on(pod, namespace) group_left kube_pod_status_phase{phase='Running'}) by (pod, namespace, node)",
 			MetricKey:   staticFields{"pod": "pod", "namespace": "namespace", "node": "node"},
 			QueryValue: &saveQueryValue{
 				ValName:         "pod-request-cpu-cores",
-				Method:          "max",
-				Factor:          maxFactor,
+				Method:          "sum",
+				Factor:          sumFactor,
 				TransformedName: "pod-request-cpu-core-seconds",
 			},
 			RowKey: "pod",
 		},
 		query{
 			Name:        "pod-request-memory-bytes",
-			QueryString: "sum(kube_pod_container_resource_requests{resource='memory'}) by (pod, namespace, node)",
+			Chunked:     true,
+			QueryString: "sum(kube_pod_container_resource_requests{resource='memory'} * on(pod, namespace) group_left kube_pod_status_phase{phase='Running'}) by (pod, namespace, node)",
 			MetricKey:   staticFields{"pod": "pod", "namespace": "namespace", "node": "node"},
 			QueryValue: &saveQueryValue{
 				ValName:         "pod-request-memory-bytes",
-				Method:          "max",
-				Factor:          maxFactor,
+				Method:          "sum",
+				Factor:          sumFactor,
 				TransformedName: "pod-request-memory-byte-seconds",
 			},
 			RowKey: "pod",
 		},
 		query{
 			Name:        "pod-usage-cpu-cores",
+			Chunked:     true,
 			QueryString: "sum(rate(container_cpu_usage_seconds_total{container!='POD',container!='',pod!=''}[5m])) BY (pod, namespace, node)",
 			MetricKey:   staticFields{"pod": "pod", "namespace": "namespace", "node": "node"},
 			QueryValue: &saveQueryValue{
@@ -187,6 +192,7 @@ var (
 		},
 		query{
 			Name:        "pod-usage-memory-bytes",
+			Chunked:     true,
 			QueryString: "sum(container_memory_usage_bytes{container!='POD', container!='',pod!=''}) by (pod, namespace, node)",
 			MetricKey:   staticFields{"pod": "pod", "namespace": "namespace", "node": "node"},
 			QueryValue: &saveQueryValue{
@@ -219,6 +225,7 @@ type querys []query
 
 type query struct {
 	Name           string
+	Chunked        bool
 	QueryString    string
 	MetricKey      staticFields
 	MetricKeyRegex regexFields
